[TOC]

## 坤同数据推送接口规范

坤同小仓库目前开放 **商品**、**库存**、**补货**、**领料** 数据实时推送。

### 推送地址

支持推送地址自定义，请求方式需为 **POST**

> [POST] https://xxxxxxxx.xxxxx.xxxx

为了保障安全，我们建议您使用 **https**，但我们也支持 **http**。
如需要接收不同类型的数据，则需要对应的推送地址。

### 接口认证

目前默认使用 **Basic Auth** 进行认证，请您提供对应的账号和密码。
不同的接口可以使用相同的账号密码，也可以分别配置不同的账号密码。

> 也支持无接口认证，为了保障数据安全，建议您使用接口认证

### 参数格式

> 以下字段可以按照需求选择接收
> 工厂编号推送字段支持映射配置

#### 商品

~~~json
[
    {
        "skuCode":"商品编号",  // 非空
        "skuName":"商品名称",  // 非空
        "factorySkuCode":"工厂商品编号",
        "factorySkuName":"工厂商品名称",
        "brand":"品牌",
        "unitName":"计量单位",
        "pack":"包装",
        "taxPrice":0, // 含税价格，非空
        "noTaxPrice":0, // 未税价格，非空
        "onSale":false // 是否在售，非空
    }
]
~~~

#### 库存

~~~json
{
    "vmCode":"机器编号",   // 非空
    "deviceCode":"设备编号",  // 非空
    "channelLabelCode":0, // 货道标签号，非空
    "skuCode":"商品编号", // 非空
    "skuName":"商品名称", // 非空
    "factorySkuCode":"工厂商品编号",
    "factorySkuName":"工厂商品名称",
    "stock":0 // 当前库存 // 非空
}
~~~

#### 补货

~~~json
{
    "tradeNumber":"交易单号，唯一",  // 非空
    "vmCode":"机器编号",  // 非空
    "deviceCode":"设备编号", // 非空
    "vmTime":"机器补货时间", // 非空
    "factoryCode":"工厂编号", // 非空
    "factoryName":"工厂名称", // 非空
    "empCode":"补货员工编号", // 非空
    "empName":"补货员工姓名", // 非空
    "items":[
        {
            "tradeItemNumber":"交易子单号，唯一", // 非空
            "channelLabelCode":"货道标签号", // 非空
            "tradeNum":0, // 领料数量，非空
            "skuCode":"商品编号", // 非空
            "skuName":"商品名称", // 非空
            "factorySkuCode":"工厂商品编号",
            "factorySkuName":"工厂商品名称",
            "taxPrice":0, // 含税价格，非空
            "noTaxPrice":0, // 未税价格，非空
            "taxStatus":false, // 客户含税未税结算状态，非空
            "unitName":"商品单位名称", 
            "pack":"商品包装"
        }
    ]
}
~~~

#### 领料

~~~json
{
    "tradeNumber":"交易单号，唯一", // 非空
    "vmCode":"机器编号", // 非空
    "deviceCode":"设备编号", // 非空
    "vmTime":"机器领料时间", // 非空
    "factoryCode":"工厂编号", // 非空
    "factoryName":"工厂名称", // 非空
    "empCode":"领料员工编号", // 非空
    "empName":"领料员工姓名", // 非空
    "empDepartmentCode":"领料员工部门编号", // 非空
    "costCode":"成本中心编号",
    "projectCode":"项目编号",
    "items":[
        {
            "tradeItemNumber":"交易子单号，唯一", // 非空
            "channelLabelCode":"货道标签号", // 非空
            "tradeNum":0, // 领料数量，非空
            "skuCode":"商品编号", // 非空
            "skuName":"商品名称", // 非空
            "factorySkuCode":"工厂商品编号",
            "factorySkuName":"工厂商品名称",
            "taxPrice":0, // 含税价格，非空
            "noTaxPrice":0, // 未税价格，非空
            "taxStatus":false, // 客户含税未税结算状态，非空
            "unitName":"商品单位名称", 
            "pack":"商品包装"
        }
    ]
}
~~~

### 返回格式

~~~json
{
    "ok": true,
    "msg": "success",
    "data": {}
}
~~~

+ **Boolean** 类型字段 **ok** 表示是否推送成功
+ **String** 类型字段 **msg** 表示接口消息，如推送失败则应返回对应失败原因
+ **Object** 类型字段 **data** 为预留字段，可以不用返回

> 如遇到网络波动等外部原因推送失败时会重新推送
> 接收到推送数据后，建议先保存数据然后接口返回，再进行后续的业务处理，防止接口同步等待业务处理