## 商品接口示例

### 接收参数

~~~java
import lombok.Getter;
import lombok.Setter;

import java.math.BigDecimal;

/**
 * 商品参数示例
 */
@Getter
@Setter
public class DemoProductParam {

    /**
     * 商品编号
     */
    private String skuCode;

    /**
     * 商品名称
     */
    private String skuName;

    /**
     * 工厂商品编号
     */
    private String factorySkuCode;

    /**
     * 工厂商品名称
     */
    private String factorySkuName;

    /**
     * 品牌
     */
    private String brand;

    /**
     * 单位名称
     */
    private String unitName;

    /**
     * 包装
     */
    private String pack;

    /**
     * 含税价格
     */
    private BigDecimal taxPrice;

    /**
     * 未税价格
     */
    private BigDecimal noTaxPrice;

    /**
     * 在售状态
     */
    private Boolean onSale;
}
~~~

### 返回体

~~~java
import lombok.Getter;
import lombok.Setter;

/**
 * 返回体示例
 */
@Getter
@Setter
public class DemoResponse {

    /**
     * 状态
     */
    private Boolean ok;

    /**
     * 消息
     */
    private String msg;

    /**
     * 保留字段
     */
    private Object data;

    public DemoResponse(Boolean ok, String msg) {
        this.ok = ok;
        this.msg = msg;
    }

    public static DemoResponse ok(String msg) {
        return new DemoResponse(Boolean.TRUE, msg);
    }

    public static DemoResponse error(String msg) {
        return new DemoResponse(Boolean.FALSE, msg);
    }
}
~~~

### 接口

~~~java
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Slf4j
@RestController
public class DemoController {

    /**
     * 商品数据接口示例
     */
    @PostMapping("/receiveProduct")
    public DemoResponse receiveProduct(@RequestBody List<DemoProductParam> list) {
        log.info("接收到商品数据：{}", JsonUtils.toJSONString(list));
        // 入库
        // ...
        return DemoResponse.ok("success");
    }
}
~~~

### 其他

+ 如果需要使用接口认证，则需要获取请求头中的认证信息进行认证
+ 接口URL支持自定义
+ 接口接收到数据后不建议直接进行业务操作，而是存库后返回，减少接口等待时间
+ 返回体中data为保留字段，作为后续业务的预留拓展，如无特殊业务需求可忽略